import 'dart:io';
import 'package:camera_camera/page/bloc/bloc_camera.dart';
import 'package:flutter/material.dart';
import 'package:camera/camera.dart';
import 'package:flutter/widgets.dart';

class Camera extends StatefulWidget {
  final ImageProvider imageMask;

  const Camera({Key key, this.imageMask}) : super(key: key);
  @override
  _CameraState createState() => _CameraState();
}

class _CameraState extends State<Camera> {
  var bloc = BlocCamera();

  @override
  void initState() {
    super.initState();
    bloc.getCameras();
    bloc.cameras.listen((data) {
      bloc.controllCamera = CameraController(data[0], ResolutionPreset.medium);
      bloc.cameraOn.sink.add(0);
      bloc.controllCamera.initialize().then((_) {
        bloc.selectCamera.sink.add(true);
      });
    });
  }

  @override
  void dispose() {
    super.dispose();
    bloc.dispose();
  }

  @override
  Widget build(BuildContext context) {
    Size size = MediaQuery.of(context).size;
    return Scaffold(
      backgroundColor: Colors.black,
      body: ConstrainedBox(
        constraints: BoxConstraints(
          maxWidth: MediaQuery.of(context).size.width,
          maxHeight: MediaQuery.of(context).size.height,
        ),
        child: Stack(
          fit: StackFit.expand,
          children: <Widget>[
            Center(
              child: StreamBuilder<File>(
                  stream: bloc.imagePath.stream,
                  builder: (context, snapshot) {
                    if (snapshot.hasData) {
                      return SizedBox(
                          width: MediaQuery.of(context).size.width,
                          height: MediaQuery.of(context).size.height,
                          child: Image.file(
                            snapshot.data,
                            
                          ));
                    } else {
                      return StreamBuilder<bool>(
                          stream: bloc.selectCamera.stream,
                          builder: (context, snapshot) {
                            return snapshot.hasData
                                ? snapshot.data
                                    ? FittedBox(
                                        
                                        fit: BoxFit.cover,
                                        child: SizedBox(
                                            width: size.height *
                                                bloc.controllCamera.value
                                                    .aspectRatio,
                                            height: size.height,
                                            child: CameraPreview(
                                                bloc.controllCamera)),
                                      )
                                    : Container()
                                : Container();
                          });
                    }
                  }),
            ),
            if (widget.imageMask != null)
              Padding(
                padding: EdgeInsets.symmetric(horizontal: 30.0),
                child: Center(
                  child: Image(
                    image: widget.imageMask,
                  ),
                ),
              ),
            Padding(
              padding: const EdgeInsets.only(bottom: 20),
              child: Align(
                alignment: Alignment.bottomCenter,
                child: StreamBuilder<Object>(
                    stream: bloc.imagePath.stream,
                    builder: (context, snapshot) {
                      return snapshot.hasData
                          ? Row(
                              mainAxisAlignment: MainAxisAlignment.spaceAround,
                              children: <Widget>[
                                CircleAvatar(
                                  child: IconButton(
                                    icon: Icon(Icons.delete, color: Colors.white),
                                    onPressed: () {
                                      bloc.deletePhoto();
                                    },
                                  ),
                                  backgroundColor: Colors.red,
                                  radius: 25.0,
                                ),
                                CircleAvatar(
                                  child: IconButton(
                                    icon: Icon(
                                      Icons.save,
                                      color: Colors.white,
                                    ),
                                    onPressed: () {
                                      Navigator.pop(
                                          context, bloc.imagePath.value);
                                    },
                                  ),
                                  backgroundColor: Colors.grey.shade900,
                                  radius: 25.0,
                                )
                              ],
                            )
                          : Row(
                              mainAxisAlignment: MainAxisAlignment.spaceAround,
                              children: <Widget>[
                                CircleAvatar(
                                  child: IconButton(
                                    icon: Icon(Icons.arrow_back,
                                        color: Colors.white),
                                    onPressed: () {
                                      Navigator.pop(context);
                                    },
                                  ),
                                  backgroundColor: Colors.grey.shade900,
                                  radius: 25.0,
                                ),
                                CircleAvatar(
                                  child: IconButton(
                                    icon: StreamBuilder<int>(
                                        stream: bloc.cameraOn,
                                        builder: (context, snapshot) {
                                          return snapshot.hasData
                                              ? snapshot.data == 0
                                                  ? Icon(
                                                      Icons.camera_front,
                                                      color: Colors.white,
                                                    )
                                                  : Icon(
                                                      Icons.camera_rear,
                                                      color: Colors.white,
                                                    )
                                              : Container();
                                        }),
                                    onPressed: () {
                                      bloc.changeCamera();
                                    },
                                  ),
                                  backgroundColor: Colors.grey.shade900,
                                  radius: 25.0,
                                )
                              ],
                            );
                    }),
              ),
            )
          ],
        ),
      ),
      floatingActionButton: Padding(
        padding: const EdgeInsets.only(bottom: 20.0),
        child: StreamBuilder<Object>(
            stream: bloc.imagePath.stream,
            builder: (context, snapshot) {
              return snapshot.hasData
                  ? Container(width: 0.0, height: 0.0)
                  /* FloatingActionButton(
                      onPressed: () {
                        bloc.cropImage();
                      },
                      child: Stack(
                        children: <Widget>[
                          Center(
                            child: CircleAvatar(
                              radius: 35.0,
                              backgroundColor: Colors.white,
                              child: Icon(
                                Icons.edit,
                                color: Colors.black,
                              ),
                            ),
                          ),
                        ],
                      ),
                      backgroundColor: Colors.grey.shade800,
                  )*/
                  : FloatingActionButton(
                      onPressed: () {
                        bloc.onTakePictureButtonPressed();
                      },
                      child: Stack(
                        children: <Widget>[
                          Center(
                            child: CircleAvatar(
                              radius: 35.0,
                              backgroundColor: Colors.white,
                            ),
                          ),
                        ],
                      ),
                      backgroundColor: Colors.grey.shade800,
                    );
            }),
      ),
      floatingActionButtonAnimator: FloatingActionButtonAnimator.scaling,
      floatingActionButtonLocation: FloatingActionButtonLocation.centerDocked,
      /*   bottomNavigationBar: BottomAppBar(
        color: Colors.transparent,
        elevation: 0.0,
        child: Padding(
          padding: const EdgeInsets.only(bottom: 8.0),
          child: StreamBuilder<Object>(
              stream: bloc.imagePath.stream,
              builder: (context, snapshot) {
                return snapshot.hasData
                    ? Row(
                        mainAxisAlignment: MainAxisAlignment.spaceAround,
                        children: <Widget>[
                          CircleAvatar(
                            child: IconButton(
                              icon: Icon(Icons.delete, color: Colors.white),
                              onPressed: () {
                                bloc.deletePhoto();
                              },
                            ),
                            backgroundColor: Colors.red,
                            radius: 25.0,
                          ),
                          CircleAvatar(
                            child: IconButton(
                              icon: Icon(
                                Icons.save,
                                color: Colors.white,
                              ),
                              onPressed: () {
                                Navigator.pop(context, bloc.imagePath.value);
                              },
                            ),
                            backgroundColor: Colors.grey.shade900,
                            radius: 25.0,
                          )
                        ],
                      )
                    : Row(
                        mainAxisAlignment: MainAxisAlignment.spaceAround,
                        children: <Widget>[
                          CircleAvatar(
                            child: IconButton(
                              icon: Icon(Icons.arrow_back, color: Colors.white),
                              onPressed: () {
                                Navigator.pop(context);
                              },
                            ),
                            backgroundColor: Colors.grey.shade900,
                            radius: 25.0,
                          ),
                          CircleAvatar(
                            child: IconButton(
                              icon: StreamBuilder<int>(
                                  stream: bloc.cameraOn,
                                  builder: (context, snapshot) {
                                    return snapshot.hasData
                                        ? snapshot.data == 0
                                            ? Icon(
                                                Icons.camera_front,
                                                color: Colors.white,
                                              )
                                            : Icon(
                                                Icons.camera_rear,
                                                color: Colors.white,
                                              )
                                        : Container();
                                  }),
                              onPressed: () {
                                bloc.changeCamera();
                              },
                            ),
                            backgroundColor: Colors.grey.shade900,
                            radius: 25.0,
                          )
                        ],
                      );
              }),
        ),
      ),*/
    );
  }
}
